summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorStef Walter <stefw@redhat.com>2014-04-17 07:16:51 +0200
committerStef Walter <stefw@gnome.org>2014-04-18 14:10:22 +0200
commit72fbac937b5bdebf0046fda5bd6e6a50d141e851 (patch)
tree8f84df99e7fcb640cba59bea14396a91e6bfcc25
parent84b5ef3a393761d48991d7630758b8cd1e6ab65d (diff)
downloadgcr-ecc.tar.gz
WIP key renderer support for ECecc
-rw-r--r--ui/gcr-key-renderer.c4
-rw-r--r--ui/gcr-key-widget.c4
2 files changed, 5 insertions, 3 deletions
diff --git a/ui/gcr-key-widget.c b/ui/gcr-key-widget.c
index 5f25501..bbaeb0d 100644
--- a/ui/gcr-key-widget.c
+++ b/ui/gcr-key-widget.c
@@ -32,7 +32,7 @@
* @title: GcrKeyWidget
* @short_description: Key widget and renderer
*
- * A #GcrKeyWidget can be used to display a RSA or DSA key. The widget
+ * A #GcrKeyWidget can be used to display a RSA, DSA or ECDSA key. The widget
* is normally in a collapsed state showing only details, but can be expanded
* by the user.
*
@@ -197,7 +197,7 @@ gcr_key_widget_new (GckAttributes *attrs)
* @attrs: (allow-none): the attributes to display
*
* Get the attributes displayed in the widget. The attributes should represent
- * either an RSA or DSA key in PKCS\#11 style.
+ * either an RSA, DSA or ECDSA key in PKCS\#11 style.
*/
void
gcr_key_widget_set_attributes (GcrKeyWidget *self, GckAttributes *attrs)
diff --git a/ui/gcr-key-renderer.c b/ui/gcr-key-renderer.c
index 0ed0bc0..f1e22f0 100644
--- a/ui/gcr-key-renderer.c
+++ b/ui/gcr-key-renderer.c
@@ -355,6 +355,8 @@ gcr_key_renderer_real_render (GcrRenderer *renderer, GcrViewer *viewer)
text = _("Private RSA Key");
else if (key_type == CKK_DSA)
text = _("Private DSA Key");
+ else if (key_type == CKK_ECDSA)
+ text = _("Private ECDSA Key");
else
text = _("Private Key");
} else if (klass == CKO_PUBLIC_KEY) {
@@ -446,7 +448,7 @@ gcr_key_renderer_new (const gchar *label, GckAttributes *attrs)
* @attrs: (allow-none): the attributes to display
*
* Get the attributes displayed in the renderer. The attributes should represent
* either an RSA or DSA key in PKCS\#11 style.
*/
void
gcr_key_renderer_set_attributes (GcrKeyRenderer *self, GckAttributes *attrs)
@@ -446,7 +448,7 @@ gcr_key_renderer_new (const gchar *label, GckAttributes *attrs)
*
* Get the attributes displayed in the renderer. The attributes should represent
- * either an RSA or DSA key in PKCS\#11 style.
+ * either an RSA, DSA, or ECDSA key in PKCS\#11 style.
*/
void